Docker Installation — satnogs-db 1.19 documentation

# Docker Installation

1. Requirements

   You will need docker and docker-compose.

2. Get the source code

   Clone source code from the repository:

       $ git clone https://gitlab.com/librespacefoundation/satnogs/satnogs-db.git
       $ cd satnogs-db

3. Configure settings

   Set your environmental variables:

       $ cp env-dist .env

4. Install frontend dependencies

   Install dependencies with `npm`:

       $ npm install

   Test and copy the newly downlodaded static assets:

       $ ./node_modules/.bin/gulp

5. Run it!

   Run satnogs-db:

       $ docker-compose up -d --build

6. Populate database

   Create, setup and populate the database with demo data:

       $ docker-compose exec web djangoctl.sh initialize

   Your satnogs-db development instance is available in localhost:8000. Go hack!